
.. If you created a package, create one automodule per module in the package.

.. If your library file(s) are nested in a directory (e.g. /adafruit_foo/foo.py)
.. use this format as the module name: "adafruit_foo.foo"

.. automodule:: adafruit_bluefruit_connect
   :members:

.. automodule:: adafruit_bluefruit_connect.packet
   :members:

.. automodule:: adafruit_bluefruit_connect.accelerometer_packet
   :members:

.. automodule:: adafruit_bluefruit_connect.button_packet
   :members:

.. automodule:: adafruit_bluefruit_connect.color_packet
   :members:

.. automodule:: adafruit_bluefruit_connect.gyro_packet
   :members:

.. automodule:: adafruit_bluefruit_connect.location_packet
   :members:

.. automodule:: adafruit_bluefruit_connect.magnetometer_packet
   :members:

.. automodule:: adafruit_bluefruit_connect.quaternion_packet
   :members:

.. automodule:: adafruit_bluefruit_connect.raw_text_packet
   :members:
